@@ -7,6 +7,5 @@ function(last)
     last <- as.integer(last)
     if(!(last %in% 1:getNumChains()))
         stop("it is required to have 1 <= last <= nchains")
-    command <- paste("SamplesEmbed.lastChain :=", last)
-    invisible(.C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs"))
+    options("BRugsSamplesLastChain" = last)
 }
