@@ -2,7 +2,7 @@ help.BRugs <- function(browser = getOption("browser"))
 {
     ## stolen from help.start()
     #    a <- system.file("OpenBUGS", "Manuals", "WinBUGS Manual.html", package="BRugs")
-    #    if (!file.exists(a)) 
+    #    if (!file.exists(a))
     #        stop("I can't find the html help")
     #    a <- chartr("/", "\\", a)
     #    message("If nothing happens, you should open `", a, "' yourself")
@@ -15,9 +15,9 @@ help.BRugs <- function(browser = getOption("browser"))
 help.WinBUGS <- function(browser = getOption("browser"))
 {
     # stolen from help.start()
-    a <- system.file("OpenBUGS", "Manuals", "Contents.html", package="BRugs")
-    if (!file.exists(a)) 
-        stop("I can't find the html help")
+    a <- file.path(options()$OpenBUGS, "Manuals", "Contents.html")
+    if (!file.exists(a))
+        stop("HTML help not found in file ", a)
     if (is.R())
       a <- chartr("/", "\\", a)
     else
